@@ -1,7 +1,7 @@
 #
 #    DeltaFi - Data transformation and enrichment platform
 #
-#    Copyright 2021-2023 DeltaFi Contributors <deltafi@deltafi.org>
+#    Copyright 2021-2025 DeltaFi Contributors <deltafi@deltafi.org>
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -20,13 +20,9 @@ from enum import Enum
 
 
 class ActionType(Enum):
-    INGRESS = "ingress"
-    TRANSFORM = "transform"
-    LOAD = "load"
-    DOMAIN = "domain"
-    ENRICH = "enrich"
-    FORMAT = "format"
-    VALIDATE = "validate"
-    EGRESS = "egress"
-    DELETE = "delete"
-    UNKNOWN = "unknown"
+    INGRESS = "INGRESS"
+    TIMED_INGRESS = "TIMED_INGRESS"
+    TRANSFORM = "TRANSFORM"
+    EGRESS = "EGRESS"
+    PUBLISH = "PUBLISH"
+    UNKNOWN = "UNKNOWN"
